aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorChen Chen <cncn@google.com>2020-10-12 13:03:48 -0700
committerChen Chen <cncn@google.com>2020-10-14 03:43:51 +0000
commit20e3b211aa8fe580db3166119fe64f0bd52ad5f5 (patch)
tree5f0bdf9d6770482588d037d4bf229c677bd1d5c8 /include
parenta3d687c25403ce45067418d0ee409e8cda822219 (diff)
downloadbt-20e3b211aa8fe580db3166119fe64f0bd52ad5f5.tar.gz
Updated SIG wording: whitelist to acceptlist
Bug: 170342881 Tag: #refactor Test: atest --host bluetooth_test_common Test: atest --host bluetooth_test_gd Test: atest net_test_btif Merged-In: I6707def7cca06068fbbf25f1f403bb5fd31eb215 BYPASS_INCLUSIVE_LANGUAGE_REASON=required to explain the update Change-Id: I6707def7cca06068fbbf25f1f403bb5fd31eb215
Diffstat (limited to 'include')
-rw-r--r--include/hardware/bt_hearing_aid.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/hardware/bt_hearing_aid.h b/include/hardware/bt_hearing_aid.h
index 191115947..1bfb42270 100644
--- a/include/hardware/bt_hearing_aid.h
+++ b/include/hardware/bt_hearing_aid.h
@@ -59,8 +59,8 @@ class HearingAidInterface {
/** Disconnect from Hearing Aid */
virtual void Disconnect(const RawAddress& address) = 0;
- /** Add a hearing aid device to white list */
- virtual void AddToWhiteList(const RawAddress& address) = 0;
+ /** Add a hearing aid device to acceptlist */
+ virtual void AddToAcceptlist(const RawAddress& address) = 0;
/** Set the volume */
virtual void SetVolume(int8_t volume) = 0;